package MyTypes::PersonID;
use strict;
use warnings;
use Class::Std::Fast::Storable constructor => 'none';
use base qw(SOAP::WSDL::XSD::Typelib::ComplexType);

Class::Std::initialize();

{ # BLOCK to scope variables

my %ID_of :ATTR(:get<ID>);

__PACKAGE__->_factory(
    [ qw(
        ID
    ) ],
    {
        ID => \%ID_of,
    },
    {
        ID => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
    }
);

} # end BLOCK






1;

=pod

=head1 NAME

MyTypes::PersonID

=head1 DESCRIPTION

Perl data type class for the XML Schema defined complextype
PersonID from the namespace http://www.example.org/benchmark/.

=head2 PROPERTIES

The following properties may be accessed using get_PROPERTY / set_PROPERTY
methods:

 ID


=head1 METHODS

=head2 new

Constructor. The following data structure may be passed to new():

 { # MyTypes::PersonID
   ID =>  $some_value, # int
 },

=head1 AUTHOR

Generated by SOAP::WSDL

=cut

